search\_in\_api package
=======================

Submodules
----------

search\_in\_api.cli module
--------------------------

.. automodule:: search_in_api.cli
    :members:
    :undoc-members:
    :show-inheritance:

search\_in\_api.search\_in\_api module
--------------------------------------

.. automodule:: search_in_api.search_in_api
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: search_in_api
    :members:
    :undoc-members:
    :show-inheritance:
